PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/density.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

density.h
Go to the documentation of this file.
1
6 #ifndef DENSITY_H
7 #define DENSITY_H
8
13 void realspace_state(double complex* x, int BAND_NUM, int KPOINT_NUM,
14 pswf_t* wf, int* fftg, int* labels, double* coords);
15
16 void remove_phase(double complex* x, int KPOINT_NUM, pswf_t* wf, int* fftg);
17
18 void ae_state_density(double* P, int BAND_NUM, int KPOINT_NUM, pswf_t* wf,
19 int* fftg, int* labels, double* coords);
20
26 void ncl_realspace_state(double complex* x, int BAND_NUM, int KPOINT_NUM,
27 pswf_t* wf, int* fftg, int* labels, double* coords);
28
33 void ae_chg_density(double* P, pswf_t* wf, int* fftg, int* labels, double* coords);
34 void ncl_ae_chg_density(double* P, pswf_t* wf, int* fftg, int* labels, double* coords);
35
40 void project_realspace_state(double complex* projs, int BAND_NUM, pswf_t* wf, pswf_t* wf_R,
41 int* fftg, int* labels, double* coords, int* labels_R, double* coords_R);
42
43 void write_realspace_state_ncl_ri(char* filename1, char* filename2,
44 char* filename3, char* filename4, int BAND_NUM, int KPOINT_NUM,
45 pswf_t* wf, int* fftg, int* labels, double* coords);
46
51 double* realspace_state_ri(int BAND_NUM, int KPOINT_NUM, pswf_t* wf, int* fftg,
52 int* labels, double* coords);
53
60 void write_volumetric(char* filename, double* x, int* fftg, double scale);
61
67 double* write_realspace_state_ri_return(char* filename1, char* filename2, int BAND_NUM, int KPOINT_NUM,
68 pswf_t* wf, int* fftg, int* labels, double* coords);
69
74 double* write_density_return(char* filename, pswf_t* wf,
75 int* fftg, int* labels, double* coords);
76
80 void write_realspace_state_ri_noreturn(char* filename1, char* filename2, int BAND_NUM, int KPOINT_NUM,
81 pswf_t* wf, int* fftg, int* labels, double* coords);
82
86 void write_density_noreturn(char* filename, pswf_t* wf,
87 int* fftg, int* labels, double* coords);
88
89 #endif
project_realspace_state
void project_realspace_state(double complex *projs, int BAND_NUM, pswf_t *wf, pswf_t *wf_R, int *fftg, int *labels, double *coords, int *labels_R, double *coords_R)
write_density_noreturn
void write_density_noreturn(char *filename, pswf_t *wf, int *fftg, int *labels, double *coords)
ncl_realspace_state
void ncl_realspace_state(double complex *x, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, int *fftg, int *labels, double *coords)
write_realspace_state_ncl_ri
void write_realspace_state_ncl_ri(char *filename1, char *filename2, char *filename3, char *filename4, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, int *fftg, int *labels, double *coords)
write_realspace_state_ri_noreturn
void write_realspace_state_ri_noreturn(char *filename1, char *filename2, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, int *fftg, int *labels, double *coords)
realspace_state_ri
double * realspace_state_ri(int BAND_NUM, int KPOINT_NUM, pswf_t *wf, int *fftg, int *labels, double *coords)
write_realspace_state_ri_return
double * write_realspace_state_ri_return(char *filename1, char *filename2, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, int *fftg, int *labels, double *coords)
write_density_return
double * write_density_return(char *filename, pswf_t *wf, int *fftg, int *labels, double *coords)
ncl_ae_chg_density
void ncl_ae_chg_density(double *P, pswf_t *wf, int *fftg, int *labels, double *coords)
write_volumetric
void write_volumetric(char *filename, double *x, int *fftg, double scale)
pawpyseed.core.quadrature.x
list x
Definition: quadrature.py:9
remove_phase
void remove_phase(double complex *x, int KPOINT_NUM, pswf_t *wf, int *fftg)
pswf
Definition: utils.h:113
ae_state_density
void ae_state_density(double *P, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, int *fftg, int *labels, double *coords)
realspace_state
void realspace_state(double complex *x, int BAND_NUM, int KPOINT_NUM, pswf_t *wf, int *fftg, int *labels, double *coords)
ae_chg_density
void ae_chg_density(double *P, pswf_t *wf, int *fftg, int *labels, double *coords)